import { HttpClient, NonNullablePaths, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Form, AddControlOptions, AddControlResponse, AddControlApplicationErrors, UpdateControlIdentifiers, UpdateControlOptions, UpdateControlResponse, UpdateControlApplicationErrors, DeleteControlIdentifiers, DeleteControlResponse, DeleteControlApplicationErrors, UpdateMessagesOptions, UpdateMessagesResponse, PublishDraftResponse, FormEventUpdatedEnvelope } from './index.typings.js';
export { ActionEvent, AddControlOptionsControlOneOf, AddControlRequest, AddControlRequestControlOneOf, AdditionalGuestsControl, Address, AddressControl, AddressControlLabels, AddressLocation, AddressStreetOneOf, Agenda, Alignment, AnchorData, AppEmbedData, AppEmbedDataAppDataOneOf, AppType, AspectRatio, AudioData, Background, BackgroundBackgroundOneOf, BackgroundType, Badge, BaseEventMetadata, BlockquoteData, BookingData, Border, BorderColors, BulletedListData, ButtonData, ButtonDataType, ButtonStyles, CalendarLinks, CaptionData, CardStyles, CardStylesType, Category, CategoryCounts, CellStyle, CheckboxControl, CheckoutFormMessages, CodeBlockData, CollapsibleListData, ColorData, Colors, ConferenceType, Crop, Dashboard, DateControl, Decoration, DecorationDataOneOf, DecorationType, DeleteControlRequest, Design, Dimensions, Direction, DiscardDraftRequest, DiscardDraftResponse, DividerData, DividerDataAlignment, DocumentStyle, DomainEvent, DomainEventBodyOneOf, DropdownControl, EmailControl, EmbedData, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, Event, EventData, EventDisplaySettings, EventStatus, EventType, EventUpdated, ExternalEvent, Feed, FileData, FileSource, FileSourceDataOneOf, FontSizeData, FontType, FormInputControlAdded, FormInputControlDeleted, FormInputControlUpdated, FormMessages, GIF, GIFData, GIFType, GalleryData, GalleryOptions, GalleryOptionsLayout, GetFormRequest, GetFormResponse, Gradient, GuestListConfig, HTMLData, HTMLDataDataOneOf, HeadingData, Height, IdentificationData, IdentificationDataIdOneOf, Image, ImageData, ImageDataStyles, ImageStyles, InitialExpandedItems, Input, InputControl, InputControlType, Item, ItemDataOneOf, ItemStyle, Keyword, Label, LabellingSettings, Labels, Layout, LayoutCellData, LayoutType, LineStyle, Link, LinkData, LinkDataOneOf, LinkPreviewData, LinkPreviewDataStyles, ListValue, Location, LocationType, MapCoordinates, MapData, MapSettings, MapType, Media, MentionData, MessageEnvelope, Metadata, Money, NameControl, NameControlLabels, Negative, NegativeResponseConfirmation, Node, NodeDataOneOf, NodeStyle, NodeType, NullValue, Occurrence, Oembed, OnlineConferencing, OnlineConferencingConfig, OnlineConferencingSession, Option, OptionDesign, OptionLayout, OptionSelection, OptionSelectionSelectedOptionOneOf, OrderedListData, Orientation, PDFSettings, ParagraphData, Permissions, PhoneControl, Placement, PlaybackOptions, PluginContainerData, PluginContainerDataAlignment, PluginContainerDataWidth, PluginContainerDataWidthDataOneOf, Poll, PollData, PollDataLayout, PollDesign, PollLayout, PollLayoutDirection, PollLayoutType, PollSettings, Position, Positive, PositiveResponseConfirmation, PublishDraftRequest, RadioButtonControl, Recurrences, Registration, RegistrationClosedMessages, RegistrationStatus, Rel, RequestedFields, Resizing, ResponseConfirmation, RestoreInfo, RibbonStyles, RichContent, RsvpCollection, RsvpCollectionConfig, RsvpFormMessages, RsvpStatusOptions, RsvpSummary, ScheduleConfig, Scheduling, SeoSchema, SeoSettings, Settings, SiteUrl, Source, Spoiler, SpoilerData, State, Status, StreetAddress, Styles, StylesBorder, StylesPosition, Subdivision, SubdivisionType, TableCellData, TableData, Tag, Target, TaxConfig, TaxType, TextAlignment, TextControl, TextData, TextNodeStyle, TextStyle, Thumbnails, ThumbnailsAlignment, Ticketing, TicketingConfig, TicketingSummary, TicketsUnavailableMessages, Type, UpdateControlIdentifiersControlOneOf, UpdateControlOptionsControlOneOf, UpdateControlRequest, UpdateControlRequestControlOneOf, UpdateMessagesRequest, ValueType, VerticalAlignment, Video, VideoData, ViewMode, ViewRole, VisitorType, VoteRole, WebhookIdentityType, Width, WidthType } from './index.typings.js';

type FormNonNullablePaths = `controls` | `controls.${number}.type` | `controls.${number}.system` | `controls.${number}.name` | `controls.${number}.label` | `controls.${number}.orderIndex` | `controls.${number}._id` | `messages.rsvp.rsvpYesOption` | `messages.rsvp.rsvpNoOption` | `messages.rsvp.positiveMessages.title` | `messages.rsvp.positiveMessages.confirmation.title` | `messages.rsvp.positiveMessages.confirmation.message` | `messages.rsvp.positiveMessages.confirmation.addToCalendarActionLabel` | `messages.rsvp.positiveMessages.confirmation.shareActionLabel` | `messages.rsvp.negativeMessages.title` | `messages.rsvp.negativeMessages.confirmation.title` | `messages.rsvp.negativeMessages.confirmation.shareActionLabel` | `messages.rsvp.submitActionLabel` | `messages.checkout.title` | `messages.checkout.submitActionLabel` | `messages.checkout.confirmation.title` | `messages.checkout.confirmation.message` | `messages.checkout.confirmation.downloadTicketsLabel` | `messages.checkout.confirmation.addToCalendarLabel` | `messages.checkout.confirmation.shareEventLabel` | `messages.registrationClosed.message` | `messages.registrationClosed.exploreEventsActionLabel` | `messages.ticketsUnavailable.message` | `messages.ticketsUnavailable.exploreEventsActionLabel`;
declare function getForm$1(httpClient: HttpClient): GetFormSignature;
interface GetFormSignature {
    /**
     * Retrieves an event registration form.
     *
     * Retrieves both the draft and published versions.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     * @returns Currently published event form.
     * Published form is visible to site visitors.
     */
    (eventId: string): Promise<NonNullablePaths<Form, FormNonNullablePaths>>;
}
declare function addControl$1(httpClient: HttpClient): AddControlSignature;
interface AddControlSignature {
    /**
     * Adds an input control to the draft form.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     */
    (eventId: string, options: AddControlOptions): Promise<NonNullablePaths<AddControlResponse, `_id` | {
        [P in FormNonNullablePaths]: `form.${P}`;
    }[FormNonNullablePaths]> & {
        __applicationErrorsType?: AddControlApplicationErrors;
    }>;
}
declare function updateControl$1(httpClient: HttpClient): UpdateControlSignature;
interface UpdateControlSignature {
    /**
     * Updates an existing input control in the draft form.
     * @param - Optional fields.
     * @param - Identifies what form to update.
     */
    (identifiers: NonNullablePaths<UpdateControlIdentifiers, `_id` | `eventId`>, options?: UpdateControlOptions): Promise<NonNullablePaths<UpdateControlResponse, {
        [P in FormNonNullablePaths]: `form.${P}`;
    }[FormNonNullablePaths]> & {
        __applicationErrorsType?: UpdateControlApplicationErrors;
    }>;
}
declare function deleteControl$1(httpClient: HttpClient): DeleteControlSignature;
interface DeleteControlSignature {
    /**
     * Deletes an input control from the draft form.
     * @param - Identifies what form to delete.
     */
    (identifiers: NonNullablePaths<DeleteControlIdentifiers, `_id` | `eventId`>): Promise<NonNullablePaths<DeleteControlResponse, {
        [P in FormNonNullablePaths]: `form.${P}`;
    }[FormNonNullablePaths]> & {
        __applicationErrorsType?: DeleteControlApplicationErrors;
    }>;
}
declare function updateMessages$1(httpClient: HttpClient): UpdateMessagesSignature;
interface UpdateMessagesSignature {
    /**
     * Updates a set of defined form messages that are displayed to a site visitor before, during, and after the registration flow.
     * Includes the configuration of form titles, response labels, "thank you" messages, and call-to-action texts.
     * @param - Event ID to which the form belongs.
     * @param - Optional fields.
     */
    (eventId: string, options?: UpdateMessagesOptions): Promise<NonNullablePaths<UpdateMessagesResponse, {
        [P in FormNonNullablePaths]: `form.${P}`;
    }[FormNonNullablePaths]>>;
}
declare function publishDraft$1(httpClient: HttpClient): PublishDraftSignature;
interface PublishDraftSignature {
    /**
     * Publishes the draft form.
     * @param - Event ID to which the form belongs.
     */
    (eventId: string): Promise<NonNullablePaths<PublishDraftResponse, {
        [P in FormNonNullablePaths]: `form.${P}`;
    }[FormNonNullablePaths]>>;
}
declare function discardDraft$1(httpClient: HttpClient): DiscardDraftSignature;
interface DiscardDraftSignature {
    /**
     * Clears all changes to the draft form.
     * @param - Event ID to which the form belongs.
     */
    (eventId: string): Promise<void>;
}
declare const onFormEventUpdated$1: EventDefinition<FormEventUpdatedEnvelope, "wix.events.events.EventUpdated">;

declare const getForm: MaybeContext<BuildRESTFunction<typeof getForm$1> & typeof getForm$1>;
declare const addControl: MaybeContext<BuildRESTFunction<typeof addControl$1> & typeof addControl$1>;
declare const updateControl: MaybeContext<BuildRESTFunction<typeof updateControl$1> & typeof updateControl$1>;
declare const deleteControl: MaybeContext<BuildRESTFunction<typeof deleteControl$1> & typeof deleteControl$1>;
declare const updateMessages: MaybeContext<BuildRESTFunction<typeof updateMessages$1> & typeof updateMessages$1>;
declare const publishDraft: MaybeContext<BuildRESTFunction<typeof publishDraft$1> & typeof publishDraft$1>;
declare const discardDraft: MaybeContext<BuildRESTFunction<typeof discardDraft$1> & typeof discardDraft$1>;
/**
 * Triggered when a form is updated or published.
 */
declare const onFormEventUpdated: BuildEventDefinition<typeof onFormEventUpdated$1>;

export { AddControlOptions, AddControlResponse, DeleteControlIdentifiers, DeleteControlResponse, Form, FormEventUpdatedEnvelope, PublishDraftResponse, UpdateControlIdentifiers, UpdateControlOptions, UpdateControlResponse, UpdateMessagesOptions, UpdateMessagesResponse, addControl, deleteControl, discardDraft, getForm, onFormEventUpdated, publishDraft, updateControl, updateMessages };
